@@ -945,7 +945,7 @@ def Pol_scan_Mapping(filename_head):
                     r, '.15f') + '\n')
                 file.close()
             if (pol_dataset.size > 0):
-                pol_dataset = np.vstack(pol_dataset, demod_x)
+                pol_dataset = np.vstack((pol_dataset, demod_x))
             else:
                 pol_dataset = demod_x
             if (pol_dataset.shape[0] >= 100):
